@@ -12,6 +12,7 @@ from .models import (
     BasePolymorphicModelFormSet,
     BasePolymorphicInlineFormSet,
     PolymorphicFormSetChild,
+    UnsupportedChildType,
     polymorphic_modelformset_factory,
     polymorphic_inlineformset_factory,
     polymorphic_child_forms_factory,
@@ -27,6 +28,7 @@ __all__ = (
     'BasePolymorphicModelFormSet',
     'BasePolymorphicInlineFormSet',
     'PolymorphicFormSetChild',
+    'UnsupportedChildType',
     'polymorphic_modelformset_factory',
     'polymorphic_inlineformset_factory',
     'polymorphic_child_forms_factory',
